function [t,X] = catchnidaq(ch, Fs, T)
% [t,X] = catchnidaq(ch, Fs, T)
% ------------------------------------------------------------------------
% This function performs the aquisition of data through the nidaq device.
%
% Input: ch - Channels to use (0..9)
%        Fs - Sampling frequency (in Hz). Maximum 200 kHz (divided over the
%        channels)
%        T - Duration (in seconds) of the data acquisition.
%
% Output: Vector t with the time corresponding to each sample and
%         a matrix X with data from each channel as columns.
%
% Example: [t,X] = catchnidaq(0:1, 1000, 5);
%          Captures 5 seconds of data from channels 0 and 1 at a rate of 1
%          kHz.
%
% ------------------------------------------------------------------------
% Created: 10/30/04 by Torbjrn Lfquist
% Latest modified: 15/04/08 by Johan Carlson
% ------------------------------------------------------------------------

if nargin < 3,
    disp('Wrong number of input arguments. Type ''help catchnidaq'' for more information.');
    return;
end;

hwinfo = daqhwinfo('nidaq');
dev = char(hwinfo.InstalledBoardIds);
AI = analoginput('nidaq',dev);

% Add channels -- Add one channel to AI. 
chan = addchannel(AI,ch);

% Configure property values -- Assign values to the basic setup properties, and create 
% the variables blocksize and Fs, which are used for subsequent analysis. The actual 
% sampling rate is retrieved because it might be set by the engine to a value that 
% differs from the specified value. 

duration = T; % Duration in seconds of data acquisition
set(AI,'SampleRate',Fs) % Sample rate (in Hz)

% Nidaq specific commands. No need to worry about this.
ActualRate = get(AI,'SampleRate');
set(AI,'SamplesPerTrigger',duration*ActualRate)
set(AI,'TriggerType','Manual')
blocksize = get(AI,'SamplesPerTrigger');

% Uncomment if you want the nidaq to acknowledge the selected sample rate
 %disp(['NIDAQ sampling frequency = ',num2str(ActualRate)]);;

% Acquire data -- Start AI, issue a manual trigger, and extract all data from the engine. 
% If winsound is the device chosen, then try to sing, clap hands or tap-dance during the 
% data aquisition time period.

% Display the time when sampling is started
disp(['Sampling started at: ', datestr(clock)])

start(AI)
trigger(AI)

% Call the nidaq to get the actual data
[X, t] = getdata(AI);

% Clean up -- When you no longer need AI, you should remove it from memory.
delete(AI)
clear AI

% Display the time when data aquisition is stopped
disp(['Sampling stopped at: ', datestr(clock)])